Index: /trunk/include/VBox/dis.h
===================================================================
--- /trunk/include/VBox/dis.h	(revision 41673)
+++ /trunk/include/VBox/dis.h	(revision 41674)
@@ -35,38 +35,38 @@
 
 
-/** CPU mode flags (DISCPUSTATE::mode).
- * @{
- */
-typedef enum
+/**
+ * CPU mode flags (DISCPUSTATE::mode).
+ */
+typedef enum DISCPUMODE
 {
-    CPUMODE_16BIT = 1,
-    CPUMODE_32BIT = 2,
-    CPUMODE_64BIT = 3,
+    CPUMODE_INVALID = 0,
+    CPUMODE_16BIT,
+    CPUMODE_32BIT,
+    CPUMODE_64BIT,
     /** hack forcing the size of the enum to 32-bits. */
     CPUMODE_MAKE_32BIT_HACK = 0x7fffffff
 } DISCPUMODE;
-/** @} */
-
-/** Prefix byte flags
+
+/** @name Prefix byte flags
  * @{
  */
 #define PREFIX_NONE                     0
 /** non-default address size. */
-#define PREFIX_ADDRSIZE                 RT_BIT(0)
+#define PREFIX_ADDRSIZE                 UINT8_C(0x00)
 /** non-default operand size. */
-#define PREFIX_OPSIZE                   RT_BIT(1)
+#define PREFIX_OPSIZE                   UINT8_C(0x01)
 /** lock prefix. */
-#define PREFIX_LOCK                     RT_BIT(2)
+#define PREFIX_LOCK                     UINT8_C(0x02)
 /** segment prefix. */
-#define PREFIX_SEG                      RT_BIT(3)
+#define PREFIX_SEG                      UINT8_C(0x04)
 /** rep(e) prefix (not a prefix, but we'll treat is as one). */
-#define PREFIX_REP                      RT_BIT(4)
+#define PREFIX_REP                      UINT8_C(0x08)
 /** rep(e) prefix (not a prefix, but we'll treat is as one). */
-#define PREFIX_REPNE                    RT_BIT(5)
+#define PREFIX_REPNE                    UINT8_C(0x10)
 /** REX prefix (64 bits) */
-#define PREFIX_REX                      RT_BIT(6)
-/** @} */
-
-/** 64 bits prefix byte flags
+#define PREFIX_REX                      UINT8_C(0x20)
+/** @} */
+
+/** @name 64 bits prefix byte flags
  * @{
  */
@@ -90,6 +90,6 @@
 /** @} */
 
-/**
- * Operand type.
+/** @name Operand type.
+ * @{
  */
 #define OPTYPE_INVALID                  RT_BIT(0)
@@ -119,7 +119,8 @@
 #define OPTYPE_MOD_FIXED_11             RT_BIT(24)  /**< modrm.mod is always 11b */
 #define OPTYPE_FORCED_32_OP_SIZE_X86    RT_BIT(25)  /**< Forced 32 bits operand size; regardless of prefix bytes (only in 16 & 32 bits mode!) */
-#define OPTYPE_ALL                      (0xffffffff)
-
-/** Parameter usage flags.
+#define OPTYPE_ALL                      UINT32_C(0xffffffff)
+/** @}  */
+
+/** @name Parameter usage flags.
  * @{
  */
@@ -507,5 +508,5 @@
     PFNDISPARSE    *pfnDisasmFnTable;
     /** Internal: instruction filter */
-    uint32_t        uFilter;
+    uint32_t        fFilter;
     /** Return code set by a worker function like the opcode bytes readers. */
     int32_t         rc;
@@ -558,10 +559,10 @@
                              PDISCPUSTATE pCpu, uint32_t *pcbInstr, char *pszOutput, size_t cbOutput);
 
-DISDECL(int) DISCoreOne(RTUINTPTR uInstrAddr, DISCPUMODE enmCpuMode, PDISCPUSTATE pCpu, uint32_t *pcbInstr);
-DISDECL(int) DISCoreOneWithReader(RTUINTPTR uInstrAddr, DISCPUMODE enmCpuMode, PFNDISREADBYTES pfnReadBytes, void *pvUser,
-                                  PDISCPUSTATE pCpu, uint32_t *pcbInstr);
-DISDECL(int) DISCoreOneExEx(RTUINTPTR uInstrAddr, DISCPUMODE enmCpuMode, uint32_t uFilter,
-                            PFNDISREADBYTES pfnReadBytes, void *pvUser,
-                            PDISCPUSTATE pCpu, uint32_t *pcbInstr);
+DISDECL(int) DISInstr(void const *pvInstr, DISCPUMODE enmCpuMode, PDISCPUSTATE pCpu, uint32_t *pcbInstr);
+DISDECL(int) DISInstrWithReader(RTUINTPTR uInstrAddr, DISCPUMODE enmCpuMode, PFNDISREADBYTES pfnReadBytes, void *pvUser,
+                                PDISCPUSTATE pCpu, uint32_t *pcbInstr);
+DISDECL(int) DISInstEx(RTUINTPTR uInstrAddr, DISCPUMODE enmCpuMode, uint32_t uFilter,
+                       PFNDISREADBYTES pfnReadBytes, void *pvUser,
+                       PDISCPUSTATE pCpu, uint32_t *pcbInstr);
 
 DISDECL(int)        DISGetParamSize(PDISCPUSTATE pCpu, POP_PARAMETER pParam);
Index: /trunk/src/VBox/Devices/PC/BIOS-new/MakeDebianBiosAssembly.cpp
===================================================================
--- /trunk/src/VBox/Devices/PC/BIOS-new/MakeDebianBiosAssembly.cpp	(revision 41673)
+++ /trunk/src/VBox/Devices/PC/BIOS-new/MakeDebianBiosAssembly.cpp	(revision 41674)
@@ -968,6 +968,6 @@
             unsigned    cbInstr;
             DISCPUSTATE CpuState;
-            int rc = DISCoreOneWithReader(uFlatAddr, fIs16Bit ? CPUMODE_16BIT : CPUMODE_32BIT,
-                                          disReadOpcodeBytes, NULL, &CpuState, &cbInstr);
+            int rc = DISInstrWithReader(uFlatAddr, fIs16Bit ? CPUMODE_16BIT : CPUMODE_32BIT,
+                                        disReadOpcodeBytes, NULL, &CpuState, &cbInstr);
             if (   RT_SUCCESS(rc)
                 && cbInstr <= cb)
Index: /trunk/src/VBox/Disassembler/Disasm.cpp
===================================================================
--- /trunk/src/VBox/Disassembler/Disasm.cpp	(revision 41673)
+++ /trunk/src/VBox/Disassembler/Disasm.cpp	(revision 41674)
@@ -96,5 +96,5 @@
                              PDISCPUSTATE pCpu, uint32_t *pcbInstr, char *pszOutput, size_t cbOutput)
 {
-    int rc = DISCoreOneExEx(uInstrAddr, enmCpuMode, uFilter, pfnReadBytes, pvUser, pCpu, pcbInstr);
+    int rc = DISInstEx(uInstrAddr, enmCpuMode, uFilter, pfnReadBytes, pvUser, pCpu, pcbInstr);
     if (RT_SUCCESS(rc) && pszOutput && cbOutput)
     {
Index: /trunk/src/VBox/Disassembler/DisasmTestCore.cpp
===================================================================
--- /trunk/src/VBox/Disassembler/DisasmTestCore.cpp	(revision 41673)
+++ /trunk/src/VBox/Disassembler/DisasmTestCore.cpp	(revision 41674)
@@ -39,5 +39,5 @@
         unsigned    cb;
         DISCPUSTATE cpu;
-        if (DISCoreOne((uintptr_t)&DISCoreOne, CPUMODE_32BIT, &cpu, &cb))
+        if (DISInstr((void *)(uintptr_t)&DISInstr, CPUMODE_32BIT, &cpu, &cb))
             printf("ok %d\n", cpu.addrmode);
         else
Index: /trunk/src/VBox/Runtime/testcase/tstLdr-3.cpp
===================================================================
--- /trunk/src/VBox/Runtime/testcase/tstLdr-3.cpp	(revision 41673)
+++ /trunk/src/VBox/Runtime/testcase/tstLdr-3.cpp	(revision 41674)
@@ -164,7 +164,7 @@
         char        szOutput[256];
         unsigned    cbInstr;
-        int rc = DISCoreOneWithReader(uNearAddr + i, pCpu->mode,
-                                      MyReadBytes, (uint8_t *)pvCodeBlock - (uintptr_t)uNearAddr,
-                                      pCpu, &cbInstr);
+        int rc = DISInstrWithReader(uNearAddr + i, pCpu->mode,
+                                    MyReadBytes, (uint8_t *)pvCodeBlock - (uintptr_t)uNearAddr,
+                                    pCpu, &cbInstr);
         RTAssertSetMayPanic(fMayPanic);
         RTAssertSetQuiet(fQuiet);
Index: /trunk/src/VBox/Runtime/testcase/tstLdrDisasmTest.cpp
===================================================================
--- /trunk/src/VBox/Runtime/testcase/tstLdrDisasmTest.cpp	(revision 41673)
+++ /trunk/src/VBox/Runtime/testcase/tstLdrDisasmTest.cpp	(revision 41674)
@@ -105,5 +105,5 @@
 {
     uint32_t cb;
-    int rc = DISCoreOneWithReader(CodeIndex, CPUMODE_32BIT, DisasmTest1ReadCode, 0, pCpu, &cb);
+    int rc = DISInstrWithReader(CodeIndex, CPUMODE_32BIT, DisasmTest1ReadCode, 0, pCpu, &cb);
     *pcb = cb;
     MY_PRINTF(("DISCoreOneEx -> rc=%d cb=%d  Cpu: opcode=%#x pCurInstr=%p (42=%d)\n", \
Index: /trunk/src/VBox/Runtime/testcase/tstLdrObj.cpp
===================================================================
--- /trunk/src/VBox/Runtime/testcase/tstLdrObj.cpp	(revision 41673)
+++ /trunk/src/VBox/Runtime/testcase/tstLdrObj.cpp	(revision 41674)
@@ -98,5 +98,5 @@
     static unsigned cb;
     DISCPUSTATE Cpu;
-    DISCoreOne((uintptr_t)SomeExportFunction3, CPUMODE_32BIT, &Cpu, &cb);
+    DISInstr((void *)(uintptr_t)SomeExportFunction3, CPUMODE_32BIT, &Cpu, &cb);
     return (void *)(uintptr_t)&SomeExportFunction1;
 }
Index: /trunk/src/VBox/Runtime/testcase/tstLdrObjR0.cpp
===================================================================
--- /trunk/src/VBox/Runtime/testcase/tstLdrObjR0.cpp	(revision 41673)
+++ /trunk/src/VBox/Runtime/testcase/tstLdrObjR0.cpp	(revision 41674)
@@ -98,5 +98,5 @@
     Cpu.mode = CPUMODE_32BIT;
 
-    DISCoreOne((uintptr_t)SomeExportFunction3, CPUMODE_32BIT, &Cpu, &cb);
+    DISInstr((void *)(uintptr_t)SomeExportFunction3, CPUMODE_32BIT, &Cpu, &cb);
     return (void *)(uintptr_t)&SomeExportFunction1;
 }
Index: /trunk/src/VBox/VMM/VMMAll/EMAll.cpp
===================================================================
--- /trunk/src/VBox/VMM/VMMAll/EMAll.cpp	(revision 41673)
+++ /trunk/src/VBox/VMM/VMMAll/EMAll.cpp	(revision 41674)
@@ -364,5 +364,5 @@
         State.GCPtr = NIL_RTGCPTR;
     }
-    return DISCoreOneWithReader(InstrGC, pDis->mode, emReadBytes, &State, pDis, pOpsize);
+    return DISInstrWithReader(InstrGC, pDis->mode, emReadBytes, &State, pDis, pOpsize);
 }
 
@@ -377,5 +377,5 @@
     State.GCPtr = InstrGC;
 
-    return DISCoreOneWithReader(InstrGC, pDis->mode, emReadBytes, &State, pDis, pOpsize);
+    return DISInstrWithReader(InstrGC, pDis->mode, emReadBytes, &State, pDis, pOpsize);
 }
 
@@ -460,5 +460,5 @@
 
     DISCPUMODE enmCpuMode = SELMGetCpuModeFromSelector(pVCpu, pCtxCore->eflags, pCtxCore->cs, (PCPUMSELREGHID)&pCtxCore->csHid);
-    rc = DISCoreOneWithReader(GCPtrInstr, enmCpuMode, emReadBytes, &State, pDis, pcbInstr);
+    rc = DISInstrWithReader(GCPtrInstr, enmCpuMode, emReadBytes, &State, pDis, pcbInstr);
     if (RT_SUCCESS(rc))
         return VINF_SUCCESS;
Index: /trunk/src/VBox/VMM/VMMR3/CPUM.cpp
===================================================================
--- /trunk/src/VBox/VMM/VMMR3/CPUM.cpp	(revision 41673)
+++ /trunk/src/VBox/VMM/VMMR3/CPUM.cpp	(revision 41674)
@@ -3676,5 +3676,5 @@
     uint32_t cbInstr;
 #ifndef LOG_ENABLED
-    rc = DISCoreOneWithReader(GCPtrPC, enmDisCpuMode, cpumR3DisasInstrRead, &State, pCpu, &cbInstr);
+    rc = DISInstrWithReader(GCPtrPC, enmDisCpuMode, cpumR3DisasInstrRead, &State, pCpu, &cbInstr);
     if (RT_SUCCESS(rc))
     {
Index: /trunk/src/VBox/VMM/VMMR3/CSAM.cpp
===================================================================
--- /trunk/src/VBox/VMM/VMMR3/CSAM.cpp	(revision 41673)
+++ /trunk/src/VBox/VMM/VMMR3/CSAM.cpp	(revision 41674)
@@ -765,5 +765,4 @@
 {
     (pCpu)->apvUserData[1] = InstrHC;
-    (pCpu)->apvUserData[2] = (void *)(uintptr_t)InstrGC; Assert(sizeof(InstrGC) <= sizeof(pCpu->apvUserData[0]));
 #ifdef DEBUG
     return DISInstrToStrEx(InstrGC, enmCpuMode, CSAMR3ReadBytes, pVM, OPTYPE_ALL,
@@ -774,6 +773,6 @@
         return DISInstrToStrEx(InstrGC, enmCpuMode, CSAMR3ReadBytes, pVM, ~(OPTYPE_INVALID | OPTYPE_HARMLESS | OPTYPE_RRM_MASK),
                                pCpu, pcbInstr, pszOutput, cbOutput);
-    return DISCoreOneExEx(InstrGC, enmCpuMode, ~(OPTYPE_INVALID | OPTYPE_HARMLESS | OPTYPE_RRM_MASK), CSAMR3ReadBytes, pVM,
-                          pCpu, pcbInstr);
+    return DISInstEx(InstrGC, enmCpuMode, ~(OPTYPE_INVALID | OPTYPE_HARMLESS | OPTYPE_RRM_MASK), CSAMR3ReadBytes, pVM,
+                     pCpu, pcbInstr);
 #endif
 }
Index: /trunk/src/VBox/VMM/VMMR3/DBGFDisas.cpp
===================================================================
--- /trunk/src/VBox/VMM/VMMR3/DBGFDisas.cpp	(revision 41673)
+++ /trunk/src/VBox/VMM/VMMR3/DBGFDisas.cpp	(revision 41674)
@@ -140,10 +140,10 @@
 
     uint32_t cbInstr;
-    int rc = DISCoreOneWithReader(GCPtr,
-                                  enmCpuMode,
-                                  dbgfR3DisasInstrRead,
-                                  &pState->Cpu,
-                                  &pState->Cpu,
-                                  &cbInstr);
+    int rc = DISInstrWithReader(GCPtr,
+                                enmCpuMode,
+                                dbgfR3DisasInstrRead,
+                                &pState->Cpu,
+                                &pState->Cpu,
+                                &cbInstr);
     if (RT_SUCCESS(rc))
     {
Index: /trunk/src/VBox/VMM/VMMR3/PATM.cpp
===================================================================
--- /trunk/src/VBox/VMM/VMMR3/PATM.cpp	(revision 41673)
+++ /trunk/src/VBox/VMM/VMMR3/PATM.cpp	(revision 41674)
@@ -603,6 +603,4 @@
     disinfo.pInstrGC    = InstrGCPtr32;
     disinfo.fReadFlags  = fReadFlags;
-    (pCpu)->pfnReadBytes = patmReadBytes;
-    (pCpu)->apvUserData[0] = &disinfo;
     return RT_SUCCESS(DISInstrToStrWithReader(InstrGCPtr32,
                                               (pPatch->flags & PATMFL_CODE32) ? CPUMODE_32BIT : CPUMODE_16BIT,
@@ -621,10 +619,8 @@
     disinfo.pInstrGC    = InstrGCPtr32;
     disinfo.fReadFlags  = fReadFlags;
-    (pCpu)->pfnReadBytes = patmReadBytes;
-    (pCpu)->apvUserData[0] = &disinfo;
-    return RT_SUCCESS(DISCoreOneWithReader(InstrGCPtr32,
-                                           (pPatch->flags & PATMFL_CODE32) ? CPUMODE_32BIT : CPUMODE_16BIT,
-                                           patmReadBytes, &disinfo,
-                                           pCpu, pcbInstr));
+    return RT_SUCCESS(DISInstrWithReader(InstrGCPtr32,
+                                         (pPatch->flags & PATMFL_CODE32) ? CPUMODE_32BIT : CPUMODE_16BIT,
+                                         patmReadBytes, &disinfo,
+                                         pCpu, pcbInstr));
 }
 
@@ -640,8 +636,6 @@
     disinfo.pInstrGC    = InstrGCPtr32;
     disinfo.fReadFlags  = fReadFlags;
-    (pCpu)->pfnReadBytes = patmReadBytes;
-    (pCpu)->apvUserData[0] = &disinfo;
-    return RT_SUCCESS(DISCoreOneWithReader(InstrGCPtr32, pPatch->uOpMode, patmReadBytes, &disinfo,
-                                           pCpu, pcbInstr));
+    return RT_SUCCESS(DISInstrWithReader(InstrGCPtr32, pPatch->uOpMode, patmReadBytes, &disinfo,
+                                         pCpu, pcbInstr));
 }
 
Index: /trunk/src/VBox/VMM/VMMR3/VMMSwitcher.cpp
===================================================================
--- /trunk/src/VBox/VMM/VMMR3/VMMSwitcher.cpp	(revision 41673)
+++ /trunk/src/VBox/VMM/VMMR3/VMMSwitcher.cpp	(revision 41674)
@@ -835,5 +835,5 @@
                 DISCPUSTATE Cpu;
                 char        szDisas[256];
-                int rc = DISCoreOne((uintptr_t)pu8CodeR3 + offCode, CPUMODE_32BIT, &Cpu, &cbInstr);
+                int rc = DISInstr(pu8CodeR3 + offCode, CPUMODE_32BIT, &Cpu, &cbInstr);
                 if (RT_SUCCESS(rc))
                 {
Index: /trunk/src/VBox/VMM/VMMRC/PATMRC.cpp
===================================================================
--- /trunk/src/VBox/VMM/VMMRC/PATMRC.cpp	(revision 41673)
+++ /trunk/src/VBox/VMM/VMMRC/PATMRC.cpp	(revision 41674)
@@ -523,5 +523,5 @@
             rc = VBOXSTRICTRC_TODO(rcStrict);
 #else
-            rc = DISCoreOne((uintptr_t)&pRec->patch.aPrivInstr[0], cpu.mode, &cpu, &cbOp);
+            rc = DISInstr(&pRec->patch.aPrivInstr[0], cpu.mode, &cpu, &cbOp);
             if (RT_FAILURE(rc))
             {

Index: /trunk/src/VBox/Disassembler/DisasmCore.cpp
===================================================================
--- /trunk/src/VBox/Disassembler/DisasmCore.cpp	(revision 41673)
+++ /trunk/src/VBox/Disassembler/DisasmCore.cpp	(revision 41674)
@@ -212,8 +212,8 @@
  *
  * @returns VBox status code.
  * @param   uInstrAddr      Address of the instruction to decode.  This is a
  *                          real address in the current context that can be
- *                          derefferenced.  (Consider DISCoreOneWithReader if
- *                          this isn't the case.)
+ *                          accessed without faulting.  (Consider
+ *                          DISInstrWithReader if this isn't the case.)
  * @param   enmCpuMode      The CPU mode. CPUMODE_32BIT, CPUMODE_16BIT, or CPUMODE_64BIT.
  * @param   pfnReadBytes    Callback for reading instruction bytes.
@@ -224,7 +224,7 @@
  *                          PDISCPUSTATE::opsize.
  */
-DISDECL(int) DISCoreOne(RTUINTPTR uInstrAddr, DISCPUMODE enmCpuMode, PDISCPUSTATE pCpu, uint32_t *pcbInstr)
-{
-    return DISCoreOneExEx(uInstrAddr, enmCpuMode, OPTYPE_ALL, NULL /*pfnReadBytes*/, NULL /*pvUser*/, pCpu, pcbInstr);
+DISDECL(int) DISInstr(const void *pvInstr, DISCPUMODE enmCpuMode, PDISCPUSTATE pCpu, uint32_t *pcbInstr)
+{
+    return DISInstEx((uintptr_t)pvInstr, enmCpuMode, OPTYPE_ALL, NULL /*pfnReadBytes*/, NULL /*pvUser*/, pCpu, pcbInstr);
 }
 
@@ -246,15 +246,13 @@
  *                          PDISCPUSTATE::opsize.
  */
-DISDECL(int) DISCoreOneWithReader(RTUINTPTR uInstrAddr, DISCPUMODE enmCpuMode, PFNDISREADBYTES pfnReadBytes, void *pvUser,
-                                  PDISCPUSTATE pCpu, uint32_t *pcbInstr)
-{
-    return DISCoreOneExEx(uInstrAddr, enmCpuMode, OPTYPE_ALL, pfnReadBytes, pvUser, pCpu, pcbInstr);
+DISDECL(int) DISInstrWithReader(RTUINTPTR uInstrAddr, DISCPUMODE enmCpuMode, PFNDISREADBYTES pfnReadBytes, void *pvUser,
+                                PDISCPUSTATE pCpu, uint32_t *pcbInstr)
+{
+    return DISInstEx(uInstrAddr, enmCpuMode, OPTYPE_ALL, pfnReadBytes, pvUser, pCpu, pcbInstr);
 }
 
 
 /**
- * Parses one guest instruction.
- *
- * The result is found in pCpu and pcbInstr.
+ * Disassembles on instruction, details in @a pCpu and length in @a pcbInstr.
  *
  * @returns VBox status code.
@@ -263,14 +261,17 @@
  * @param   enmCpuMode      The CPU mode. CPUMODE_32BIT, CPUMODE_16BIT, or CPUMODE_64BIT.
  * @param   pfnReadBytes    Callback for reading instruction bytes.
  * @param   uFilter         Instruction type filter.
  * @param   pvUser          User argument for the instruction reader. (Ends up in apvUserData[0].)
- * @param   pCpu            Pointer to cpu structure. Will be initialized.
- * @param   pcbInstr        Where to store the size of the instruction.
- *                          NULL is allowed.  This is also stored in
- *                          PDISCPUSTATE::opsize.
+ * @param   pCpu            Pointer to CPU structure. With the exception of
+ *                          DISCPUSTATE::apvUserData[1] and
+ *                          DISCPUSTATE::apvUserData[2], the structure will be
+ *                          completely initialized by this API, i.e. no input is
+ *                          taken from it.
+ * @param   pcbInstr        Where to store the size of the instruction.  (This
+ *                          is also stored in PDISCPUSTATE::opsize.)  Optional.
  */
-DISDECL(int) DISCoreOneExEx(RTUINTPTR uInstrAddr, DISCPUMODE enmCpuMode, uint32_t uFilter,
-                            PFNDISREADBYTES pfnReadBytes, void *pvUser,
-                            PDISCPUSTATE pCpu, uint32_t *pcbInstr)
+DISDECL(int) DISInstEx(RTUINTPTR uInstrAddr, DISCPUMODE enmCpuMode, uint32_t fFilter,
+                       PFNDISREADBYTES pfnReadBytes, void *pvUser,
+                       PDISCPUSTATE pCpu, uint32_t *pcbInstr)
 {
     const OPCODE *paOneByteMap;
@@ -299,5 +300,5 @@
     pCpu->uInstrAddr        = uInstrAddr;
     pCpu->pfnDisasmFnTable  = g_apfnFullDisasm;
-    pCpu->uFilter           = uFilter;
+    pCpu->fFilter           = fFilter;
     pCpu->rc                = VINF_SUCCESS;
     pCpu->pfnReadBytes      = pfnReadBytes ? pfnReadBytes : disReadBytesDefault;
@@ -451,7 +452,7 @@
     /*
      * Apply filter to instruction type to determine if a full disassembly is required.
-     * @note Multibyte opcodes are always marked harmless until the final byte.
+     * Note! Multibyte opcodes are always marked harmless until the final byte.
      */
-    if ((pOp->optype & pCpu->uFilter) == 0)
+    if ((pOp->optype & pCpu->fFilter) == 0)
     {
         fFiltered = true;
@@ -541,5 +542,5 @@
      * @note Multibyte opcodes are always marked harmless until the final byte.
      */
-    if ((fpop->optype & pCpu->uFilter) == 0)
+    if ((fpop->optype & pCpu->fFilter) == 0)
         pCpu->pfnDisasmFnTable = g_apfnCalcSize;
     else
@@ -212,8 +212,8 @@
  *
  * @returns VBox status code.
- * @param   uInstrAddr      Address of the instruction to decode.  This is a
+ * @param   pvInstr         Address of the instruction to decode.  This is a
  *                          real address in the current context that can be
@@ -263,14 +261,17 @@
  * @param   enmCpuMode      The CPU mode. CPUMODE_32BIT, CPUMODE_16BIT, or CPUMODE_64BIT.
  * @param   pfnReadBytes    Callback for reading instruction bytes.
- * @param   uFilter         Instruction type filter.
+ * @param   fFilter         Instruction type filter.
  * @param   pvUser          User argument for the instruction reader. (Ends up in apvUserData[0].)